@@ -39,6 +39,8 @@
 #include "fsk.h"
 #include "fskioUI.h"
 
+#include "fileselect.h"
+
 Fl_Light_Button *btnPOWER = (Fl_Light_Button *)0;
 
 // controls for touch screen interface
@@ -212,6 +214,7 @@ Hspinner *spnr_cw_spot_tone = (Hspinner *)0;
 Hspinner *spnr_cw_qsk = (Hspinner *)0;
 Hspinner *spnr_cw_weight = (Hspinner *)0;
 Hspinner *spnr_cw_wpm = (Hspinner *)0;
+Hspinner *spnr_cw_vol = (Hspinner *)0;
 Fl_Check_Button *btn_enable_keyer = (Fl_Check_Button *)0;
 
 Fl_Group *genericQSK = (Fl_Group *)0;
@@ -414,6 +417,7 @@ static const char *mtr_scales[] = {
 "50 watt",
 "100 watt",
 "200 watt",
+"200 watt log",
 "Auto scaled"};
 
 void select_power_meter_scales() {
@@ -470,8 +474,60 @@ static void cb_mnu_embed_tabs(Fl_Menu_*, void*) {
 		
 }
 
+static void cb_save_as_prefs(Fl_Menu_*, void*) {
+	std::string deffname = RigHomeDir;
+	deffname.append("NEW.UI");
+	std::string fname = FSEL::saveas(
+		"Save as prefs file",
+		"*.UI.prefs",
+		deffname.c_str());
+	if (fname.empty()) return;
+	size_t p = fname.find(".prefs");
+	if (p != std::string::npos) fname.erase(p);
+	p = fname.rfind("/");
+	if (p != std::string::npos) fname.erase(0, p + 1);
+	p = fname.rfind("\\");
+	if (p != std::string::npos) fname.erase(0, p+ 1);
+	p = fname.rfind(".UI");
+	if (p == std::string::npos) fname.append(".UI");
+	progStatus.ui_name = fname;
+	progStatus.saveScheme(fname);
+}
+
+static void cb_save_prefs(Fl_Menu_*, void*) {
+	std::string deffname = RigHomeDir;
+	deffname.append(progStatus.ui_name);
+	progStatus.saveScheme(deffname);
+}
+
+static void cb_load_prefs(Fl_Menu_*, void*) {
+	std::string defname = RigHomeDir;
+	defname.append("default.UI");
+	std::string fname = FSEL::select(
+		"Load prefs from file",
+		"*.UI.prefs",
+		defname.c_str());
+	if (fname.empty())
+		return;
+	size_t p = fname.find(".prefs");
+	if (p != std::string::npos) fname.erase(p);
+	p = fname.rfind("/");
+	if (p != std::string::npos) fname.erase(0, p + 1);
+	p = fname.rfind("\\");
+	if (p != std::string::npos) fname.erase(0, p+ 1);
+	progStatus.ui_name = fname;
+	progStatus.loadScheme(fname);
+	set_system_colors();
+	setColors();
+	Fl::scheme(progStatus.ui_scheme.c_str());
+}
+
 static void cb_mnuColorConfig(Fl_Menu_*, void*) {
-	setDisplayColors();
+	open_colors_dialog();
+}
+
+static void cb_mnuUIConfig(Fl_Menu_*, void*) {
+	setUIscheme();
 }
 
 static void cb_mnu_show_meters(Fl_Menu_ *, void *) {
@@ -579,21 +635,21 @@ static void cb_mnuCLIENT(Fl_Menu_*, void*) {
 }
 
 static void cb_mnuOnLineHelp(Fl_Menu_*, void*) {
-	visit_URL((void *)("http://www.w1hkj.com/flrig-help/index.html"));
+	visit_URL((void *)("https://www.w1hkj.org/flrig-help/index.html"));
 }
 
 static void cb_mnuAbout(Fl_Menu_*, void*) {
 	about();
 }
 
-static void cb_btnALC_IDD_SWR(Fl_Button*, void*) {
-	cbALC_IDD_SWR();
-}
-
 static void cb_btnAGC(Fl_Button*, void*) {
 	cbAGC();
 }
 
+static void cb_btnALC_IDD_SWR(Fl_Button*, void*) {
+        cbALC_IDD_SWR();
+}
+
 static void cb_scalePower(Fl_Button*, void*) {
 	if (Fl::event_button() == FL_RIGHT_MOUSE)
 		select_power_meter_scales();
@@ -820,6 +876,11 @@ static void cb_spnr_cw_spot_tone(Hspinner* o, void*) {
 	cb_cw_spot_tone();
 }
 
+static void cb_spnr_cw_vol(Hspinner* o, void*) {
+	progStatus.cw_vol=(int)o->value();
+	cb_cw_vol();
+}
+
 static void cb_spnr_cw_qsk(Hspinner* o, void*) {
 	progStatus.cw_qsk = o->value();
 	cb_cw_qsk();
@@ -846,7 +907,7 @@ static void cb_btn_enable_keyer(Fl_Check_Button* o, void*) {
 }
 
 static void cb_btnBreakIn(Fl_Check_Button* o, void*) {
-	if (xcvr_name == rig_IC7300.name_) {
+	if (xcvr_name == rig_IC7300.name_ || xcvr_name == rig_IC7610.name_) {
 		progStatus.break_in++;
 		if (progStatus.break_in == 3)
 			progStatus.break_in = 0;
@@ -957,57 +1018,57 @@ static void cb_btn_xcvr_synch_now( Fl_Button *o, void *) {
 void exec_btnUser( int val, bool shift) {
 	if (shift) {
 		switch (val) {
-			case 1: cb_send_command(progStatus.shftcmd1, cmdResponse); break;
-			case 2: cb_send_command(progStatus.shftcmd2, cmdResponse); break;
-			case 3: cb_send_command(progStatus.shftcmd3, cmdResponse); break;
-			case 4: cb_send_command(progStatus.shftcmd4, cmdResponse); break;
-			case 5: cb_send_command(progStatus.shftcmd5, cmdResponse); break;
-			case 6: cb_send_command(progStatus.shftcmd6, cmdResponse); break;
-			case 7: cb_send_command(progStatus.shftcmd7, cmdResponse); break;
-			case 8: cb_send_command(progStatus.shftcmd8, cmdResponse); break;
-			case 9: cb_send_command(progStatus.shftcmd9, cmdResponse); break;
-			case 10: cb_send_command(progStatus.shftcmd10, cmdResponse); break;
-			case 11: cb_send_command(progStatus.shftcmd11, cmdResponse); break;
-			case 12: cb_send_command(progStatus.shftcmd12, cmdResponse); break;
-			case 13: cb_send_command(progStatus.shftcmd13, cmdResponse); break;
-			case 14: cb_send_command(progStatus.shftcmd14, cmdResponse); break;
-			case 15: cb_send_command(progStatus.shftcmd15, cmdResponse); break;
-			case 16: cb_send_command(progStatus.shftcmd16, cmdResponse); break;
-			case 17: cb_send_command(progStatus.shftcmd17, cmdResponse); break;
-			case 18: cb_send_command(progStatus.shftcmd18, cmdResponse); break;
-			case 19: cb_send_command(progStatus.shftcmd19, cmdResponse); break;
-			case 20: cb_send_command(progStatus.shftcmd20, cmdResponse); break;
-			case 21: cb_send_command(progStatus.shftcmd21, cmdResponse); break;
-			case 22: cb_send_command(progStatus.shftcmd22, cmdResponse); break;
-			case 23: cb_send_command(progStatus.shftcmd23, cmdResponse); break;
-			case 24: cb_send_command(progStatus.shftcmd24, cmdResponse); break;
+			case 1: cb_send_command(progStatus.shftcmd1, cmdResponse, progStatus.expect1); break;
+			case 2: cb_send_command(progStatus.shftcmd2, cmdResponse, progStatus.expect2); break;
+			case 3: cb_send_command(progStatus.shftcmd3, cmdResponse, progStatus.expect3); break;
+			case 4: cb_send_command(progStatus.shftcmd4, cmdResponse, progStatus.expect4); break;
+			case 5: cb_send_command(progStatus.shftcmd5, cmdResponse, progStatus.expect5); break;
+			case 6: cb_send_command(progStatus.shftcmd6, cmdResponse, progStatus.expect6); break;
+			case 7: cb_send_command(progStatus.shftcmd7, cmdResponse, progStatus.expect7); break;
+			case 8: cb_send_command(progStatus.shftcmd8, cmdResponse, progStatus.expect8); break;
+			case 9: cb_send_command(progStatus.shftcmd9, cmdResponse, progStatus.expect9); break;
+			case 10: cb_send_command(progStatus.shftcmd10, cmdResponse, progStatus.expect10); break;
+			case 11: cb_send_command(progStatus.shftcmd11, cmdResponse, progStatus.expect11); break;
+			case 12: cb_send_command(progStatus.shftcmd12, cmdResponse, progStatus.expect12); break;
+			case 13: cb_send_command(progStatus.shftcmd13, cmdResponse, progStatus.expect13); break;
+			case 14: cb_send_command(progStatus.shftcmd14, cmdResponse, progStatus.expect14); break;
+			case 15: cb_send_command(progStatus.shftcmd15, cmdResponse, progStatus.expect15); break;
+			case 16: cb_send_command(progStatus.shftcmd16, cmdResponse, progStatus.expect16); break;
+			case 17: cb_send_command(progStatus.shftcmd17, cmdResponse, progStatus.expect17); break;
+			case 18: cb_send_command(progStatus.shftcmd18, cmdResponse, progStatus.expect18); break;
+			case 19: cb_send_command(progStatus.shftcmd19, cmdResponse, progStatus.expect19); break;
+			case 20: cb_send_command(progStatus.shftcmd20, cmdResponse, progStatus.expect20); break;
+			case 21: cb_send_command(progStatus.shftcmd21, cmdResponse, progStatus.expect21); break;
+			case 22: cb_send_command(progStatus.shftcmd22, cmdResponse, progStatus.expect22); break;
+			case 23: cb_send_command(progStatus.shftcmd23, cmdResponse, progStatus.expect23); break;
+			case 24: cb_send_command(progStatus.shftcmd24, cmdResponse, progStatus.expect24); break;
 		}
 	} else {
 		switch (val) {
-			case 1: cb_send_command(progStatus.command1, cmdResponse); break;
-			case 2: cb_send_command(progStatus.command2, cmdResponse); break;
-			case 3: cb_send_command(progStatus.command3, cmdResponse); break;
-			case 4: cb_send_command(progStatus.command4, cmdResponse); break;
-			case 5: cb_send_command(progStatus.command5, cmdResponse); break;
-			case 6: cb_send_command(progStatus.command6, cmdResponse); break;
-			case 7: cb_send_command(progStatus.command7, cmdResponse); break;
-			case 8: cb_send_command(progStatus.command8, cmdResponse); break;
-			case 9: cb_send_command(progStatus.command9, cmdResponse); break;
-			case 10: cb_send_command(progStatus.command10, cmdResponse); break;
-			case 11: cb_send_command(progStatus.command11, cmdResponse); break;
-			case 12: cb_send_command(progStatus.command12, cmdResponse); break;
-			case 13: cb_send_command(progStatus.command13, cmdResponse); break;
-			case 14: cb_send_command(progStatus.command14, cmdResponse); break;
-			case 15: cb_send_command(progStatus.command15, cmdResponse); break;
-			case 16: cb_send_command(progStatus.command16, cmdResponse); break;
-			case 17: cb_send_command(progStatus.command17, cmdResponse); break;
-			case 18: cb_send_command(progStatus.command18, cmdResponse); break;
-			case 19: cb_send_command(progStatus.command19, cmdResponse); break;
-			case 20: cb_send_command(progStatus.command20, cmdResponse); break;
-			case 21: cb_send_command(progStatus.command21, cmdResponse); break;
-			case 22: cb_send_command(progStatus.command22, cmdResponse); break;
-			case 23: cb_send_command(progStatus.command23, cmdResponse); break;
-			case 24: cb_send_command(progStatus.command24, cmdResponse); break;
+			case 1: cb_send_command(progStatus.command1, cmdResponse, progStatus.expect1); break;
+			case 2: cb_send_command(progStatus.command2, cmdResponse, progStatus.expect2); break;
+			case 3: cb_send_command(progStatus.command3, cmdResponse, progStatus.expect3); break;
+			case 4: cb_send_command(progStatus.command4, cmdResponse, progStatus.expect4); break;
+			case 5: cb_send_command(progStatus.command5, cmdResponse, progStatus.expect5); break;
+			case 6: cb_send_command(progStatus.command6, cmdResponse, progStatus.expect6); break;
+			case 7: cb_send_command(progStatus.command7, cmdResponse, progStatus.expect7); break;
+			case 8: cb_send_command(progStatus.command8, cmdResponse, progStatus.expect8); break;
+			case 9: cb_send_command(progStatus.command9, cmdResponse, progStatus.expect9); break;
+			case 10: cb_send_command(progStatus.command10, cmdResponse, progStatus.expect10); break;
+			case 11: cb_send_command(progStatus.command11, cmdResponse, progStatus.expect11); break;
+			case 12: cb_send_command(progStatus.command12, cmdResponse, progStatus.expect12); break;
+			case 13: cb_send_command(progStatus.command13, cmdResponse, progStatus.expect13); break;
+			case 14: cb_send_command(progStatus.command14, cmdResponse, progStatus.expect14); break;
+			case 15: cb_send_command(progStatus.command15, cmdResponse, progStatus.expect15); break;
+			case 16: cb_send_command(progStatus.command16, cmdResponse, progStatus.expect16); break;
+			case 17: cb_send_command(progStatus.command17, cmdResponse, progStatus.expect17); break;
+			case 18: cb_send_command(progStatus.command18, cmdResponse, progStatus.expect18); break;
+			case 19: cb_send_command(progStatus.command19, cmdResponse, progStatus.expect19); break;
+			case 20: cb_send_command(progStatus.command20, cmdResponse, progStatus.expect20); break;
+			case 21: cb_send_command(progStatus.command21, cmdResponse, progStatus.expect21); break;
+			case 22: cb_send_command(progStatus.command22, cmdResponse, progStatus.expect22); break;
+			case 23: cb_send_command(progStatus.command23, cmdResponse, progStatus.expect23); break;
+			case 24: cb_send_command(progStatus.command24, cmdResponse, progStatus.expect24); break;
 		}
 	}
 }
@@ -1313,6 +1374,8 @@ void cb_offset(Fl_Button *b, void*)
 
 #include "ui_setup.cxx"
 
+#include "ui_colors.cxx"
+
 #include "ui_memory.cxx"
 
 #include "xcvr_setup.cxx"
