@@ -49,7 +49,13 @@ Fl_Menu_Item menu_small_menu[] = {
  {_("Embed tabs"), 0, (Fl_Callback*)cb_mnu_embed_tabs, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Tooltips"), 0,  (Fl_Callback*)cb_mnuTooltips, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Voltmeter"), 0, (Fl_Callback*)cb_mnuVoltmeter, 0, 130, FL_NORMAL_LABEL, 0, 14, 0},
- {_("User Interface"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Configuration"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("User Interface"), 0,  (Fl_Callback*)cb_mnuUIConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Controls Colors"), 0,  (Fl_Callback*)cb_mnuColorConfig, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Save prefs"), 0, (Fl_Callback*)cb_save_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Save As prefs"), 0, (Fl_Callback*)cb_save_as_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Load prefs"), 0, (Fl_Callback*)cb_load_prefs, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+ {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
  {0,0,0,0,0,0,0,0,0},
  {_("&Memory"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
@@ -149,7 +155,7 @@ Fl_Group *small_main_group(int X, int Y, int W, int H)
 	sldrSQUELCH->labelcolor(FL_FOREGROUND_COLOR);
 	sldrSQUELCH->maximum(100);
 	sldrSQUELCH->step(1);
-	sldrSQUELCH->value(15);
+	sldrSQUELCH->value(progStatus.squelch);
 	sldrSQUELCH->textsize(12);
 	sldrSQUELCH->callback((Fl_Callback*)cb_sldrSQUELCH);
 	sldrSQUELCH->align(Fl_Align(FL_ALIGN_LEFT));
@@ -318,6 +324,8 @@ Fl_Group *small_main_group(int X, int Y, int W, int H)
 	btnPOWER = new Fl_Light_Button(2, 305, 50, 18, _("Pwr"));
 	btnPOWER->tooltip(_("Enable/Disable Power adjuster"));
 	btnPOWER->value(1);
+	btnPOWER->down_box(FL_THIN_DOWN_BOX);
+	btnPOWER->labelsize(12);
 	btnPOWER-> callback((Fl_Callback*) cb_btnPOWER);
 
 	sldrPOWER = new Fl_Wheel_Value_Slider(54, 305, 156, 18, "");
@@ -589,12 +597,16 @@ CTRL  click: FreqB -> FreqA\
 
 	btn_tune_on_off = new Fl_Light_Button(294, 325, 20, 18, "");
 	btn_tune_on_off->tooltip("Tuner On/Off");
+	btn_tune_on_off->down_box(FL_THIN_DOWN_BOX);
+	btn_tune_on_off->labelsize(12);
 	btn_tune_on_off->callback((Fl_Callback*)cb_btn_tune_on_off);
 
 	btnTune = new Fl_Button(
 		btn_tune_on_off->x() + btn_tune_on_off->w(),
 		btn_tune_on_off->y(), 40, 18, _("Tune"));
 	btnTune->tooltip(_("Manual Tune"));
+	btnTune->down_box(FL_THIN_DOWN_BOX);
+	btnTune->labelsize(12);
 	btnTune->callback((Fl_Callback*)cb_btnTune);
 
 	btnPTT = new Fl_Light_Button(
@@ -602,6 +614,8 @@ CTRL  click: FreqB -> FreqA\
 		btnTune->y(), 60, 18, _("PTT"));
 //	362, 325, 60, 18, _("PTT"));
 	btnPTT->tooltip(_("Xmt On/Off"));
+	btnPTT->down_box(FL_THIN_DOWN_BOX);
+	btnPTT->labelsize(12);
 	btnPTT->callback((Fl_Callback*)cb_btnPTT);
 
 	sm_grp1 = new Fl_Group(1, 62, 210, 60);
@@ -1436,8 +1450,8 @@ Fl_Double_Window *tabs_window()
 			genericCW->hide();
 
 			spnr_cw_wpm = new Hspinner(
-				4, 40,
-				85, 22, _("wpm"), 18);
+				4, 32,
+				85, 20, _("wpm"), 15);
 			spnr_cw_wpm->type(1);
 			spnr_cw_wpm->minimum(5);
 			spnr_cw_wpm->maximum(80);
@@ -1449,8 +1463,8 @@ Fl_Double_Window *tabs_window()
 			spnr_cw_wpm->tooltip(_("CW words per minute"));
 
 			spnr_cw_weight = new Hspinner(
-				spnr_cw_wpm->x() + spnr_cw_wpm->w() + 4, 40,
-				85, 22, _("Weight"), 18);
+				spnr_cw_wpm->x() + spnr_cw_wpm->w() + 4, 32,
+				85, 20, _("Weight"), 16);
 			spnr_cw_weight->type(1);
 			spnr_cw_weight->minimum(2.5);
 			spnr_cw_weight->maximum(4.5);
@@ -1463,8 +1477,8 @@ Fl_Double_Window *tabs_window()
 			spnr_cw_weight->tooltip(_("CW weight"));
 
 			spnr_cw_spot_tone= new Hspinner(
-				spnr_cw_weight->w() + spnr_cw_weight->x() + 4, 40,
-				85, 22, _("Spot tone"), 18);
+				spnr_cw_weight->w() + spnr_cw_weight->x() + 4, 32,
+				85, 20, _("Spot tone"), 16);
 			spnr_cw_spot_tone->tooltip(_("Spot volume"));
 			spnr_cw_spot_tone->type(1);
 			spnr_cw_spot_tone->minimum(50);
@@ -1476,15 +1490,29 @@ Fl_Double_Window *tabs_window()
 			spnr_cw_spot_tone->labelsize(12);
 			spnr_cw_spot_tone->align(FL_ALIGN_BOTTOM | FL_ALIGN_CENTER);
 
+			spnr_cw_vol= new Hspinner(
+				spnr_cw_spot_tone->w() + spnr_cw_spot_tone->x() + 4, 32,
+				85, 20, _("CW vol"), 18);
+			spnr_cw_vol->tooltip(_("CW volume"));
+			spnr_cw_vol->type(1);
+			spnr_cw_vol->minimum(0);
+			spnr_cw_vol->maximum(100);
+			spnr_cw_vol->step(1);
+			spnr_cw_vol->value(50);
+			spnr_cw_vol->callback((Fl_Callback*)cb_spnr_cw_vol);
+			spnr_cw_vol->value(progStatus.cw_vol);
+			spnr_cw_vol->labelsize(12);
+			spnr_cw_vol->align(FL_ALIGN_BOTTOM | FL_ALIGN_CENTER);
+
 			btnSpot = new Fl_Light_Button(
-				spnr_cw_spot_tone->x() + spnr_cw_spot_tone->w() + 4, 36,
-				60, 22, _("Spot"));
+				spnr_cw_vol->x() + spnr_cw_vol->w() + 4, 32,
+				50, 20, _("Spot"));
 			btnSpot->tooltip(_("Spot tone on/off"));
 			btnSpot->callback((Fl_Callback*)cb_btnSpot);
 			btnSpot->value(progStatus.cw_spot);
 
 			btn_enable_keyer = new Fl_Check_Button(
-				btnSpot->x(), 62, 60, 15, _("Keyer"));
+				btnSpot->x(), 56, 60, 15, _("Keyer"));
 			btn_enable_keyer->tooltip(_("Enable internal keyer"));
 			btn_enable_keyer->down_box(FL_DOWN_BOX);
 			btn_enable_keyer->callback((Fl_Callback*)cb_btn_enable_keyer);
