@@ -52,7 +52,7 @@ public:
 	bool can_split();
 	void set_split(bool);
 	int  get_split();
-
+	void A2B();
 	bool canswap() { return true; }
 	void swapAB();
 
@@ -154,9 +154,6 @@ public:
 	int  get_attenuator();
 	int  next_attenuator(){return 0;}
 
-	const char * PRE_label();
-	const char * ATT_label();
-
 	void set_noise(bool val);
 	int  get_noise();
 	void set_nb_level(int val);
