@@ -142,39 +142,22 @@ static int IC7610_bw_vals_AM[] = {
 40,41,42,43,44,45,46,47,48,49
 WVALS_LIMIT};
 
-static const char *IC7610_bcd_vals[] = {
-"0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
-"10", "11", "12", "13", "14", "15", "16", "17", "18", "19",
-"20", "21", "22", "23", "24", "25", "26", "27", "28", "29",
-"30", "31", "32", "33", "34", "35", "36", "37", "38", "39",
-"40", "41", "42", "43", "44", "45", "46", "47", "48", "49",
-"50", "51", "52", "53", "54", "55", "56", "57", "58", "59",
-"60", "61", "62", "63", "64", "65", "66", "67", "68", "69",
-"70", "71", "72", "73", "74", "75", "76", "77", "78", "79",
-"80", "81", "82", "83", "84", "85", "86", "87", "88", "89",
-"90", "91", "92", "93", "94", "95", "96", "97", "98", "99",
-"100", "101", "102", "103", "104", "105", "106", "107", "108", "109",
-"110", "111", "112", "113", "114", "115", "116", "117", "118", "119",
-"120", "121", "122", "123", "124", "125", "126", "127", "128", "129",
-"130", "131", "132", "133", "134", "135", "136", "137", "138", "139",
-"140", "141", "142", "143", "144", "145", "146", "147", "148", "149",
-"150", "151", "152", "153", "154", "155", "156", "157", "158", "159",
-"160", "161", "162", "163", "164", "165", "166", "167", "168", "169",
-"170", "171", "172", "173", "174", "175", "176", "177", "178", "179",
-"180", "181", "182", "183", "184", "185", "186", "187", "188", "189",
-"190", "191", "192", "193", "194", "195", "196", "197", "198", "199",
-"200", "201", "202", "203", "204", "205", "206", "207", "208", "209",
-"210", "211", "212", "213", "214", "215", "216", "217", "218", "219",
-"220", "221", "222", "223", "224", "225", "226", "227", "228", "229",
-"230", "231", "232", "233", "234", "235", "236", "237", "238", "239",
-"240", "241", "242", "243", "244", "245", "246", "247", "248", "249",
-"250", "251", "252", "253", "254", "255" };
-
 static std::vector<std::string>IC7610_fm_bws;
 static const char *vIC7610_fm_bws[] =
 { "FIXED" };
 static int IC7610_bw_vals_FM[] = { 1, WVALS_LIMIT};
 
+//----------------------------------------------------------------------
+static std::vector<std::string>IC7610_att_labels;
+static const char *vIC7610_att_labels[] = {
+"ATT","3db","6db","9db","12db","15db","18db","21db",
+"24db","27db","30db","33db","36db","39db","42db","45db"
+};
+
+static std::vector<std::string>IC7610_pre_labels;
+static const char *vIC7610_pre_labels[] = { "PRE", "Pre 1", "Pre 2"};
+//----------------------------------------------------------------------
+
 static GUI IC7610_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },	//0
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },	//1
@@ -208,6 +191,12 @@ void RIG_IC7610::initialize()
 
 	_mode_type = IC7610_mode_type;
 
+	VECTOR (IC7610_att_labels, vIC7610_att_labels);
+	VECTOR (IC7610_pre_labels, vIC7610_pre_labels);
+
+	att_labels_ = IC7610_att_labels;
+	pre_labels_ = IC7610_pre_labels;
+
 	IC7610_widgets[0].W = btnVol;
 	IC7610_widgets[1].W = sldrVOLUME;
 	IC7610_widgets[2].W = btnAGC;
@@ -287,6 +276,7 @@ RIG_IC7610::RIG_IC7610() {
 
 	has_micgain_control = true;
 	has_bandwidth_control = true;
+	has_sql_control = true;
 
 	has_smeter = true;
 
@@ -335,6 +325,8 @@ RIG_IC7610::RIG_IC7610() {
 	can_change_alt_vfo = true;
 	has_a2b = true;
 
+	ICOMmainsub = true;
+
 	can_synch_clock = true;
 };
 
@@ -373,7 +365,25 @@ void RIG_IC7610::swapAB()
 	cmd = pre_to;
 	cmd += 0x07; cmd += 0xB0;
 	cmd.append(post);
+
+	set_trace(1, "swap AB");
 	waitFB("Exchange vfos");
+	seth();
+
+	get_modeA(); // get mode to update the filter A / B usage
+	get_modeB();
+}
+
+void RIG_IC7610::A2B()
+{
+	cmd = pre_to;
+	cmd += 0x07; cmd += 0xB1;
+	cmd.append(post);
+
+	set_trace(1, "swap AB");
+	waitFB("Exchange vfos");
+	seth();
+
 	get_modeA(); // get mode to update the filter A / B usage
 	get_modeB();
 }
@@ -458,6 +468,8 @@ unsigned long long RIG_IC7610::get_vfoA ()
 	return A.freq;
 }
 
+// 00 XX XX XX XX 00
+
 void RIG_IC7610::set_vfoA (unsigned long long freq)
 {
 	A.freq = freq;
@@ -498,6 +510,8 @@ unsigned long long RIG_IC7610::get_vfoB ()
 	return B.freq;
 }
 
+// 01 xx xx xx xx 00
+
 void RIG_IC7610::set_vfoB (unsigned long long freq)
 {
 	B.freq = freq;
@@ -514,11 +528,11 @@ void RIG_IC7610::set_vfoB (unsigned long long freq)
 
 // expecting
 //  0  1  2  3  4  5  6  7  8  9
-// FE FE E0 94 26 NN NN NN NN FD
+// FE FE E0 98 26 00 NN NN NN FD
 //                |  |  |  |
 //                |  |  |  |__filter setting, 01, 02, 03
-//                |  |  |_____data mode, 00 - off, 01 - data mode 1
-//                |  |  |_____02 - data mode 2, 03 - data mode 3
+//                |  |  |_____data mode, 00 - off,         01 - data mode 1
+//                |  |  |_____           02 - data mode 2, 03 - data mode 3
 //                |  |________Mode 00 - LSB
 //                |                01 - USB
 //                |                02 - AM
@@ -527,8 +541,13 @@ void RIG_IC7610::set_vfoB (unsigned long long freq)
 //                |                05 - FM
 //                |                07 - CW-R
 //                |                08 - RTTY-R
-//                |___________selected vfo, 00 - active, 01 - inactive
+//                |                12 - PSK
+//                |                13 - PSK-R
+//                |___________selected vfo, 00 - main, 01 - sub
 
+// query
+// FE FE 98 E0 26 00 FD
+ 
 int RIG_IC7610::get_modeA()
 {
 	int md = 0;
@@ -541,25 +560,37 @@ int RIG_IC7610::get_modeA()
 	cmd += '\x00';
 	cmd.append(post);
 
-	if (waitFOR(10, "get mode A")) {
-		p = replystr.rfind(resp);
-		if (p == std::string::npos)
-			goto end_wait_modeA;
+/*
+replystr = resp;
+replystr += '\x00';
+replystr += '\x01';
+replystr += '\x02';
+replystr += '\x01';
+replystr += '\xFD';
+	{
+*/
+//  FE FE E0 98 26 00 03 00 01 FD
 
-		if (replystr[p+6] == -1) { A.imode = A.filter = 0; return A.imode; }
+	if (waitFOR(10, "get_mode A")) {
+		p = replystr.rfind(resp);
+		if (p == std::string::npos) {
+			goto end_wait_modeA;
+		}
+
+		if (replystr[p+6] == '\xFB') {
+			A.imode = A.filter = 0;
+			goto end_wait_modeA;
+		}
 
 		for (md = 0; md < m7610LSBD1; md++) {
 			if (replystr[p+6] == IC7610_mode_nbr[md]) {
 				A.imode = md;
 				if (replystr[p+7] == 0x01 && A.imode < 4)
 					A.imode += 10;
-				if (replystr[p+7] == 0x02 && A.imode < 4)
+				else if (replystr[p+7] == 0x02 && A.imode < 4)
 					A.imode += 14;
-				if (replystr[p+7] == 0x03 && A.imode < 4)
+				else if (replystr[p+7] == 0x03 && A.imode < 4)
 					A.imode += 18;
-				if (A.imode > 21)
-					A.imode = 1;
-				break;
 			}
 			A.filter = replystr[p+8];
 		}
@@ -567,7 +598,7 @@ int RIG_IC7610::get_modeA()
 
 end_wait_modeA:
 	get_trace(4, 
-		"get mode A[",
+		"get_mode A[",
 		IC7610modes_[A.imode].c_str(), 
 		"] ", 
 		str2hex(replystr.c_str(), replystr.length()));
@@ -597,15 +628,35 @@ void RIG_IC7610::set_modeA(int val)
 		cmd += '\x00';
 	cmd += mode_filterA[A.imode];		// filter
 	cmd.append( post );
-	waitFB("set mode A");
 
 	set_trace(4, 
-		"set mode A[",
+		"set_mode A[",
 		IC7610modes_[A.imode].c_str(), 
 		"] ", 
 		str2hex(cmd.c_str(), cmd.length()));
+
+	waitFB("set_mode A");
 }
 
+// expecting
+//  0  1  2  3  4  5  6  7  8  9
+// FE FE E0 98 26 01 NN NN NN FD
+//                |  |  |  |
+//                |  |  |  |__filter setting, 01, 02, 03
+//                |  |  |_____data mode, 00 - off,         01 - data mode 1
+//                |  |  |_____           02 - data mode 2, 03 - data mode 3
+//                |  |________Mode 00 - LSB
+//                |                01 - USB
+//                |                02 - AM
+//                |                03 - CW
+//                |                04 - RTTY
+//                |                05 - FM
+//                |                07 - CW-R
+//                |                08 - RTTY-R
+//                |                12 - PSK
+//                |                13 - PSK-R
+//                |___________selected vfo, 00 - main, 01 - sub
+
 int RIG_IC7610::get_modeB()
 {
 	int md = 0;
@@ -618,25 +669,32 @@ int RIG_IC7610::get_modeB()
 	cmd += '\x01';
 	cmd.append(post);
 
-	if (waitFOR(10, "get mode B")) {
+//replystr = resp;
+//replystr += '\x01';
+//replystr += '\x03';
+//replystr += '\x00';
+//replystr += '\x02';
+//replystr += '\xFD';
+//	{
+	if (waitFOR(10, "get_mode_B")) {
 		p = replystr.rfind(resp);
 		if (p == std::string::npos)
 			goto end_wait_modeB;
 
-		if (replystr[p+6] == -1) { B.imode = B.filter = 0; return B.imode; }
+		if (replystr[p+6] == -1) {
+			B.imode = B.filter = 0; 
+			goto end_wait_modeB;
+		}
 
 		for (md = 0; md < m7610LSBD1; md++) {
 			if (replystr[p+6] == IC7610_mode_nbr[md]) {
 				B.imode = md;
 				if (replystr[p+7] == 0x01 && B.imode < 4)
 					B.imode += 10;
-				if (replystr[p+7] == 0x02 && B.imode < 4)
+				else if (replystr[p+7] == 0x02 && B.imode < 4)
 					B.imode += 14;
-				if (replystr[p+7] == 0x03 && B.imode < 4)
+				else if (replystr[p+7] == 0x03 && B.imode < 4)
 					B.imode += 18;
-				if (B.imode > 21)
-					B.imode = 1;
-				break;
 			}
 		}
 		B.filter = replystr[p+8];
@@ -644,7 +702,7 @@ int RIG_IC7610::get_modeB()
 
 end_wait_modeB:
 	get_trace(4, 
-		"get mode B[",
+		"get_mode_B[",
 		IC7610modes_[B.imode].c_str(), 
 		"] ", 
 		str2hex(replystr.c_str(), replystr.length()));
@@ -671,13 +729,14 @@ void RIG_IC7610::set_modeB(int val)
 		cmd += '\x00';
 	cmd += mode_filterB[B.imode];		// filter
 	cmd.append( post );
-	waitFB("set mode B");
 
 	set_trace(4, 
-		"set mode B[",
+		"set_mode B[",
 		IC7610modes_[B.imode].c_str(), 
 		"] ", 
 		str2hex(cmd.c_str(), cmd.length()));
+
+	waitFB("set_mode B");
 }
 
 int RIG_IC7610::get_FILT(int mode)
@@ -705,10 +764,10 @@ void RIG_IC7610::set_FILT(int filter)
 			cmd += '\x00';
 		cmd += filter;						// filter
 		cmd.append( post );
-		waitFB("set mode/filter B");
+		waitFB("set_mode/filter B");
 
 		set_trace(4, 
-			"set mode/filter B[",
+			"set_mode/filter B[",
 			IC7610modes_[B.imode].c_str(), 
 			"] ", 
 			str2hex(cmd.c_str(), cmd.length()));
@@ -729,9 +788,9 @@ void RIG_IC7610::set_FILT(int filter)
 			cmd += '\x00';
 		cmd += filter;						// filter
 		cmd.append( post );
-		waitFB("set mode/filter A");
+		waitFB("set_mode/filter A");
 
-		set_trace(4, "set mode/filter A[",
+		set_trace(4, "set_mode/filter A[",
 			IC7610modes_[A.imode].c_str(), 
 			"] ", 
 			str2hex(cmd.c_str(), cmd.length()));
@@ -1197,14 +1256,16 @@ void RIG_IC7610::set_break_in()
 	cmd.assign(pre_to).append("\x16\x47");
 
 	switch (progStatus.break_in) {
-		case 2: cmd += '\x02'; break_in_label("FULL"); break;
+		default:
+		case 0: cmd += '\x00'; break_in_label("BK-IN"); break;
 		case 1: cmd += '\x01'; break_in_label("SEMI");  break;
-		case 0:
-		default: cmd += '\x00'; break_in_label("BK-IN");
+		case 2: cmd += '\x02'; break_in_label("FULL"); break;
 	}
+
 	cmd.append(post);
+	set_trace(1, "set QSK");
 	waitFB("SET break-in");
-	set_trace(2, "set_break_in() ", str2hex(cmd.c_str(), cmd.length()));
+	seth();
 }
 
 int RIG_IC7610::get_break_in()
@@ -1212,19 +1273,26 @@ int RIG_IC7610::get_break_in()
 	cmd.assign(pre_to).append("\x16\x47").append(post);
 	std::string resp;
 	resp.assign(pre_fm);
-	if (waitFOR(8, "get break in")) {
+
+	get_trace(1, "get_break_in()");
+	int ret = waitFOR(8, "get break in");
+	geth();
+
+	if (ret) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
 			progStatus.break_in = replystr[p+6];
-			if (progStatus.break_in == 0) break_in_label("qsk");
-			else  if (progStatus.break_in == 1) break_in_label("SEMI");
-			else  break_in_label("FULL");
+			switch (progStatus.break_in) {
+				default:
+				case 0 : break_in_label("BK-IN"); break;
+				case 1 : break_in_label("SEMI"); break;
+				case 2 : break_in_label("FULL"); break;
+			}
 		}
 	}
 	return progStatus.break_in;
 }
 
-
 void RIG_IC7610::get_cw_qsk_min_max_step(double &min, double &max, double &step)
 {
 	min = 2.0; max = 13.0; step = 0.1;
@@ -1446,9 +1514,7 @@ double RIG_IC7610::get_voltmeter()
 	return -1;
 }
 
-struct pwrpair {int mtr; float pwr;};
-
-static pwrpair pwrtbl[] = { 
+static meterpair pwrtbl[] = { 
 	{0, 0.0},
 	{21, 5.0},
 	{43,10.0}, 
@@ -1477,13 +1543,13 @@ int RIG_IC7610::get_power_out(void)
 		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
-			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+			for (i = 0; i < sizeof(pwrtbl) / sizeof(meterpair) - 1; i++)
 				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
 					break;
 			if (mtr < 0) mtr = 0;
 			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(pwrtbl[i].pwr + 
-				(pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+			mtr = (int)ceil(pwrtbl[i].val + 
+				(pwrtbl[i+1].val - pwrtbl[i].val)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
 			
 			if (mtr > 100) mtr = 100;
 		}
@@ -1491,13 +1557,11 @@ int RIG_IC7610::get_power_out(void)
 	return mtr;
 }
 
-struct swrpair {int mtr; float swr;};
-
 // Table entries below correspond to SWR readings of 1.1, 1.5, 2.0, 2.5, 3.0 and infinity.
 // Values are also tweaked to fit the display of the SWR meter.
 
 
-static swrpair swrtbl[] = { 
+static meterpair swrtbl[] = { 
 	{0, 0.0},
 	{48, 10.5},
 	{80, 23.0}, 
@@ -1521,13 +1585,13 @@ int RIG_IC7610::get_swr(void)
 		if (p != std::string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
 			size_t i = 0;
-			for (i = 0; i < sizeof(swrtbl) / sizeof(swrpair) - 1; i++)
+			for (i = 0; i < sizeof(swrtbl) / sizeof(meterpair) - 1; i++)
 				if (mtr >= swrtbl[i].mtr && mtr < swrtbl[i+1].mtr)
 					break;
 			if (mtr < 0) mtr = 0;
 			if (mtr > 255) mtr = 255;
-			mtr = (int)ceil(swrtbl[i].swr + 
-				(swrtbl[i+1].swr - swrtbl[i].swr)*(mtr - swrtbl[i].mtr)/(swrtbl[i+1].mtr - swrtbl[i].mtr));
+			mtr = (int)ceil(swrtbl[i].val + 
+				(swrtbl[i+1].val - swrtbl[i].val)*(mtr - swrtbl[i].mtr)/(swrtbl[i+1].mtr - swrtbl[i].mtr));
 
 			if (mtr > 100) mtr = 100;
 		}
@@ -1589,7 +1653,7 @@ void RIG_IC7610::get_rf_min_max_step(double &min, double &max, double &step)
 
 int RIG_IC7610::next_preamp()
 {
-	switch (preamp_level) {
+	switch (preamp_state) {
 		case 0: return 1;
 		case 1: return 2;
 		case 2: return 0;
@@ -1603,12 +1667,12 @@ void RIG_IC7610::set_preamp(int val)
 	cmd += '\x16';
 	cmd += '\x02';
 
-	preamp_level = val;
+	preamp_state = val;
 
-	cmd += (unsigned char)preamp_level;
+	cmd += (unsigned char)preamp_state;
 	cmd.append( post );
-	waitFB(	(preamp_level == 0) ? "set Preamp OFF" :
-			(preamp_level == 1) ? "set Preamp Level 1" :
+	waitFB(	(preamp_state == 0) ? "set Preamp OFF" :
+			(preamp_state == 1) ? "set Preamp Level 1" :
 			"set Preamp Level 2");
 	set_trace(2, "set_preamp() ", str2hex(cmd.c_str(), cmd.length()));
 }
@@ -1624,11 +1688,11 @@ int RIG_IC7610::get_preamp()
 	if (waitFOR(8, "get Preamp Level")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			preamp_level = replystr[p+6];
+			preamp_state = replystr[p+6];
 		}
 	}
 	get_trace(2, "get_preamp() ", str2hex(replystr.c_str(), replystr.length()));
-	return preamp_level;
+	return preamp_state;
 }
 
 static char attval[] = {
@@ -1637,11 +1701,6 @@ static char attval[] = {
 '\x30', '\x33', '\x36', '\x39', '\x42',
 '\x45' };
 
-std::string attstr[] = {
-"OFF","3db","6db","9db","12db","15db","18db","21db",
-"24db","27db","30db","33db","36db","39db","42db","45db"
-};
-
 void RIG_IC7610::set_index_att(int v)
 {
 	if (v < 0) return;
@@ -1666,10 +1725,10 @@ int RIG_IC7610::get_attenuator()
 	if (waitFOR(7, "get ATT")) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			atten_level = replystr[p+5];
+			atten_state = replystr[p+5];
 			size_t i = 0;
 			for (i = 0; i < sizeof(attval); i++) {
-				if (attval[i] == atten_level) {
+				if (attval[i] == atten_state) {
 					progStatus.index_ic7610att = i;
 					break;
 				}
@@ -1680,24 +1739,6 @@ int RIG_IC7610::get_attenuator()
 	return progStatus.index_ic7610att;
 }
 
-const char *RIG_IC7610::PRE_label()
-{
-	switch (preamp_level) {
-		case 0: default:
-			return "PRE"; break;
-		case 1:
-			return "Amp 1"; break;
-		case 2:
-			return "Amp 2"; break;
-	}
-	return "PRE";
-}
-
-const char *RIG_IC7610::ATT_label()
-{
-	return attstr[progStatus.index_ic7610att].c_str();
-}
-
 void RIG_IC7610::set_noise(bool val)
 {
 	cmd = pre_to;
@@ -1861,13 +1902,16 @@ int  RIG_IC7610::get_squelch()
 
 void RIG_IC7610::set_auto_notch(int val)
 {
+	progStatus.auto_notch = an_level = val;
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x41';
 	cmd += (unsigned char)val;
 	cmd.append( post );
+	set_trace(1, "set auto notch");
 	waitFB("set AN");
-	set_trace(2, "set_auto_notch() ", str2hex(cmd.c_str(), cmd.length()));
+	seth();
+	auto_notch_label(an_label(), an_level ? true : false);
 }
 
 int RIG_IC7610::get_auto_notch()
@@ -1878,17 +1922,16 @@ int RIG_IC7610::get_auto_notch()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(8, "get AN")) {
-		get_trace(2, "get_auto_notch() ", str2hex(replystr.c_str(), replystr.length()));
+
+	get_trace(1, "get_auto_notch()");
+	int ret = waitFOR(8, "get AN");
+	geth();
+
+	if (ret) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			if (replystr[p+6] == 0x01) {
-				auto_notch_label("AN", true);
-				return true;
-			} else {
-				auto_notch_label("AN", false);
-				return false;
-			}
+			progStatus.auto_notch = an_level = replystr[p+6];
+			auto_notch_label(an_label(), an_level ? true : false);
 		}
 	}
 	return progStatus.auto_notch;
@@ -1959,7 +2002,6 @@ void RIG_IC7610::get_notch_min_max_step(int &min, int &max, int &step)
 	step = 20;
 }
 
-static int agcval = 3;
 int  RIG_IC7610::get_agc()
 {
 	cmd = pre_to;
@@ -2039,32 +2081,27 @@ void RIG_IC7610::get_if_min_max_step(int &min, int &max, int &step)
 
 void RIG_IC7610::set_pbt_inner(int val)
 {
-	int shift = 128 + val * 128 / 50;
-	if (shift < 0) shift = 0;
-	if (shift > 255) shift = 255;
-
 	cmd = pre_to;
 	cmd.append("\x14\x07");
-	cmd.append(to_bcd(shift, 3));
+	cmd.append(bcd255(val + 50));
 	cmd.append(post);
+	set_trace(1, "set_pbt_inner()");
 	waitFB("set PBT inner");
-	set_trace(4, "set_pbt_inner(", IC7610_bcd_vals[shift], ") ", str2hex(cmd.c_str(), cmd.length()));
+	seth();
 }
 
 void RIG_IC7610::set_pbt_outer(int val)
 {
-	int shift = 128 + val * 128 / 50;
-	if (shift < 0) shift = 0;
-	if (shift > 255) shift = 255;
-
 	cmd = pre_to;
 	cmd.append("\x14\x08");
-	cmd.append(to_bcd(shift, 3));
+	cmd.append(bcd255(val + 50));
 	cmd.append(post);
+	set_trace(1, "set_pbt_outer()");
 	waitFB("set PBT outer");
-	set_trace(4, "set_pbt_outer(", IC7610_bcd_vals[shift], ") ", str2hex(cmd.c_str(), cmd.length()));
+	seth();
 }
 
+// response xFE xFE x93 xE0 x14 x07 xXX xXX xFD;
 int RIG_IC7610::get_pbt_inner()
 {
 	int val = 0;
@@ -2074,21 +2111,25 @@ int RIG_IC7610::get_pbt_inner()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+
+	get_trace(1, "get_pbt_inner()");
+	int ret = waitFOR(9, "get pbt inner");
+	geth();
+
+	if (ret) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			val = num100(replystr.substr(p+6));
-			val -= 50;
+			val = num100(replystr.substr(p+6)) - 50;
 		}
 	}
-	get_trace(2, "get_pbt_inner()", str2hex(replystr.c_str(), replystr.length()));
+
 	return val;
 }
 
 int RIG_IC7610::get_pbt_outer()
 {
-	get_dual_watch();
-	get_digi_sel();
+//	get_dual_watch();
+//	get_digi_sel();
 
 	int val = 0;
 	std::string cstr = "\x14\x08";
@@ -2097,14 +2138,17 @@ int RIG_IC7610::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt outer")) {
+
+	get_trace(1, "get_pbt_outer");
+	int ret = waitFOR(9, "get pbt outer");
+	geth();
+
+	if (ret) {
 		size_t p = replystr.rfind(resp);
 		if (p != std::string::npos) {
-			val = num100(replystr.substr(p+6));
-			val -= 50;
+			val = num100(replystr.substr(p+6)) - 50;
 		}
 	}
-	get_trace(2, "get_pbt_outer()", str2hex(replystr.c_str(), replystr.length()));
 	return val;
 }
 
@@ -2146,27 +2190,30 @@ void RIG_IC7610::set_digi_sel(bool b)
 	cmd.append(post);
 	waitFB("set_digi_sel");
 	set_trace(2, "set_digi_sel()", str2hex(cmd.c_str(), cmd.length()));
+	progStatus.digi_sel_on_off = b;
 }
 
 int RIG_IC7610::get_digi_sel()
 {
-	cmd = pre_to;
-	cmd.append("\x16\x4E");
-	cmd.append(post);
-	if (waitFOR(8, "get AGC")) {
-		size_t p = replystr.find(pre_fm);
-		if (p != std::string::npos)
-			progStatus.digi_sel_on_off = replystr[p+6];
-	}
-	get_trace(2, "get_digi_sel() ", str2hex(replystr.c_str(), replystr.length()));
+	// there is no get for digi_sel
 	return progStatus.digi_sel_on_off;
+//	cmd = pre_to;
+//	cmd.append("\x16\x4E");
+//	cmd.append(post);
+//	if (waitFOR(8, "get AGC")) {
+//		size_t p = replystr.find(pre_fm);
+//		if (p != std::string::npos)
+//			progStatus.digi_sel_on_off = replystr[p+6];
+//	}
+//	get_trace(2, "get_digi_sel() ", str2hex(replystr.c_str(), replystr.length()));
+//	return progStatus.digi_sel_on_off;
 }
 
 void RIG_IC7610::set_digi_val(int v)
 {
 	cmd = pre_to;
 	cmd.append("\x14\x13");
-	cmd.append(to_bcd(v, 3));
+	cmd.append(bcd255(v));
 	cmd.append(post);
 	waitFB("set_digi_val");
 	set_trace(2, "set_digi_val()", str2hex(cmd.c_str(), cmd.length()));
@@ -2207,10 +2254,9 @@ int RIG_IC7610::get_dual_watch()
 	cmd += '\xC2';
 	cmd.append(post);
 	std::string resp = pre_fm;
-	cmd += '\x07'; cmd += '\xC2';
-	if (waitFOR(8, "get dual watch")) {
+	if (waitFOR(9, "get dual watch")) {
 		size_t p = replystr.rfind(resp);
-		progStatus.dual_watch = replystr[p+7];
+		progStatus.dual_watch = (replystr[p+6] == 0x01);
 	}
 	get_trace(2, "get_dual_watch()", str2hex(replystr.c_str(), replystr.length()));
 	Fl::awake(set_ic7610_dual_watch);
@@ -2351,6 +2397,7 @@ void RIG_IC7610::set_band_selection(int v)
 
 }
 
+// 1A 05 01 58 &  1A 05 01 59
 // ---------------------------------------------------------------------
 // set date and time
 // 1A 05 00 95 HH MM : set time
@@ -2363,7 +2410,7 @@ void RIG_IC7610::sync_date(char *dt)
 	cmd.clear();
 	cmd.append(pre_to);
 	cmd += '\x1A'; cmd += '\x05';
-	cmd += '\x01'; cmd += '\x59';
+	cmd += '\x01'; cmd += '\x58';
 	unsigned char val;
 	val = ((dt[0] - '0') << 4) + (dt[1] - '0');
 	cmd += (val & 0xFF);
@@ -2387,7 +2434,7 @@ void RIG_IC7610::sync_clock(char *tm)
 	cmd.clear();
 	cmd.append(pre_to);
 	cmd += '\x1A'; cmd += '\x05';
-	cmd += '\x01'; cmd += '\x60';
+	cmd += '\x01'; cmd += '\x59';
 	unsigned char val;
 	val = ((tm[0] - '0') << 4) + (tm[1] - '0');
 	cmd += (val & 0xFF);
