@@ -92,9 +92,9 @@ void TRACED(adjust_small_ui)
 			btnPOWER->redraw();
 			btnPOWER->show();
 		}
-		if (mnuSchema) mnuSchema->set();
+		if (mnuScheme) mnuSchema->set();
 	} else {
-		if (mnuSchema) mnuSchema->clear();
+		if (mnuScheme) mnuSchema->clear();
 		y = grpMeters->y() + grpMeters->h() - 18;
 		if (selrig->has_volume_control) {
 			y += 20;
@@ -296,6 +296,10 @@ void TRACED(adjust_small_ui)
 			mnuVoltmeter->clear();
 	}
 
+	Fl_Color clr = fl_rgb_color( progStatus.tab_red, progStatus.tab_green, progStatus.tab_blue);
+	tabsGeneric->selection_color(clr);
+	tabs550->selection_color(clr);
+
 	if (mnuEmbedTabs) {
 		if (progStatus.embed_tabs) mnuEmbedTabs->set();
 		else mnuEmbedTabs->clear();
@@ -857,10 +861,22 @@ void TRACED(init_Generic_Tabs)
 			spnr_cw_spot_tone->maximum(max);
 			spnr_cw_spot_tone->step(step);
 			spnr_cw_spot_tone->value(progStatus.cw_spot_tone);
-			selrig->set_cw_spot_tone();
+			selrig->get_cw_spot_tone();
 		} else
 			spnr_cw_spot_tone->hide();
 
+		if (selrig->has_cw_vol) {
+			spnr_cw_vol->show();
+			int min, max, step;
+			selrig->get_cw_vol_min_max_step(min, max, step);
+			spnr_cw_vol->minimum(min);
+			spnr_cw_vol->maximum(max);
+			spnr_cw_vol->step(step);
+			selrig->get_cw_vol();
+			spnr_cw_vol->value(progStatus.cw_vol);
+		} else
+			spnr_cw_vol->hide();
+
 		tabsGeneric->add(genericCW);
 		genericCW->redraw();
 		genericCW->show();
@@ -2774,30 +2790,38 @@ void TRACED(initStatusConfigDialog)
 				LOG_WARN("No comm port ... test mode");
 			} else if (!progStatus.xmlrpc_rig) {
 				fl_alert2("\
-Cannot open %s!\n\n\
+Cannot open %s!\n\
+Error: %s\n\n\
+Is Rig turned on?\n\n\
 Check serial (COM) port connection\n\
 Open menu Config/Setup/Transceiver\n\
 Press 'Update' button, reselect port\n\n\
-Press 'Init' button.", progStatus.xcvr_serial_port.c_str());
-				LOG_WARN("Cannot open %s", progStatus.xcvr_serial_port.c_str());
-				progStatus.xcvr_serial_port = "NONE";
-				selectCommPort->value(progStatus.xcvr_serial_port.c_str());
+Press 'Init' button.",
+					progStatus.xcvr_serial_port.c_str(),strerror(errno));
+				LOG_WARN("Failed to open %s: %s", progStatus.xcvr_serial_port.c_str(), strerror(errno));
 			}
 			box_xcvr_connect->color(FL_BACKGROUND2_COLOR);
 			box_xcvr_connect->redraw();
 		}
 		if ( progStatus.aux_serial_port != "NONE") {
 			if (!startAuxSerial()) {
-				LOG_WARN("Cannot open %s", progStatus.aux_serial_port.c_str());
-				progStatus.aux_serial_port = "NONE";
-				selectAuxPort->value(progStatus.aux_serial_port.c_str());
+				fl_alert2("\
+Cannot open %s!\n\n\
+Error: %s\n\n\
+Check auxiliary serial (COM) port connection",
+					progStatus.aux_serial_port.c_str(), strerror(errno));
+				LOG_WARN("Faialed to open %s: %s", progStatus.aux_serial_port.c_str(), strerror(errno));
 			}
 		}
 		if ( progStatus.sep_serial_port != "NONE") {
 			if (!startSepSerial()) {
-				LOG_WARN("Cannot open %s", progStatus.sep_serial_port.c_str());
-				progStatus.sep_serial_port = "NONE";
-				selectSepPTTPort->value(progStatus.sep_serial_port.c_str());
+				fl_alert2("\
+Cannot open %s!\n\
+Error: %s\n\n\
+Check separate serial (COM) port connection",
+					progStatus.sep_serial_port.c_str(), strerror(errno));
+				LOG_WARN("Failed to open %s: %s",
+					progStatus.sep_serial_port.c_str(), strerror(errno));
 			}
 		}
 	}
